@@ -56,6 +56,7 @@ class OpenStackConfig(object):
         defaults.add('insecure')
         defaults.add('endpoint_type')
         defaults.add('cacert')
+        defaults.add('auth_type')
 
         self.defaults = defaults
 
@@ -75,7 +76,11 @@ class OpenStackConfig(object):
                 return yaml.load(open(path, 'r'))
 
     def _get_regions(self, cloud):
-        return self.cloud_config['clouds'][cloud]['region_name']
+        try:
+            return self.cloud_config['clouds'][cloud]['region_name']
+        except KeyError:
+            # No region configured
+            return ''
 
     def _get_region(self, cloud):
         return self._get_regions(cloud).split(',')[0]
@@ -90,11 +95,17 @@ class OpenStackConfig(object):
         else:
             our_cloud = dict()
 
+        # Get the defaults (including env vars) first
+        cloud.update(self.defaults)
+
         # yes, I know the next line looks silly
         if 'cloud' in our_cloud:
-            cloud.update(vendors.CLOUD_DEFAULTS[our_cloud['cloud']])
+            try:
+                cloud.update(vendors.CLOUD_DEFAULTS[our_cloud['cloud']])
+            except KeyError:
+                # Can't find the requested vendor config, go about business
+                pass
 
-        cloud.update(self.defaults)
         cloud.update(our_cloud)
         if 'cloud' in cloud:
             del cloud['cloud']
